[yum-commits] Branch 'yum-3_2_X' - yummain.py

Ville Skyttä scop at osuosl.org
Tue Sep 27 21:07:02 UTC 2011


 yummain.py |    6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

New commits:
commit 05a86271effaf9ddf25c3674d0103910920c6fd3
Author: Ville Skyttä <ville.skytta at iki.fi>
Date:   Wed Sep 28 00:05:00 2011 +0300

    Fix comment, log output, and else block of cwd read/exec check.
    
    http://lists.baseurl.org/pipermail/yum-devel/2011-September/008660.html

diff --git a/yummain.py b/yummain.py
index 4b1112a..58179d2 100755
--- a/yummain.py
+++ b/yummain.py
@@ -102,15 +102,15 @@ def main(args):
         return exFatal(e)
 
     # Try to open the current directory to see if we have 
     # read and write access. If not, chdir to /
     try:
         f = open(".")
     except IOError, e:
         if e.errno == errno.EACCES:
-            logger.critical(_('No read/write access in current directory, moving to /'))
+            logger.critical(_('No read/execute access in current directory, moving to /'))
             os.chdir("/")
     else:
-        close(f)
+        f.close()
 
     lockerr = ""
     while True:
@@ -102,15 +102,15 @@ def main(args):
 
     # Try to open the current directory to see if we have 
-    # read and write access. If not, chdir to /
+    # read and execute access. If not, chdir to /
     try:
         f = open(".")


More information about the Yum-commits mailing list